@@ -1,3 +1,7 @@
+# based on tube mover calibration by Theo Sanderson
+# github https://github.com/theosanderson/tube_checkout
+
+
 import atexit
 import json
 import subprocess
@@ -9,8 +13,10 @@ from opentrons.protocol_api import ProtocolContext
 
 from ondine_laser_control import laser
 
+print("Starting...")
+
 movement_distances = {"0": 0.1, "1": 1, "2": 10}
-movement_distance = 0.1
+movement_distance = None
 
 
 # from https://github.com/theosanderson/tube_checkout
@@ -65,6 +71,7 @@ def set_button_as_kill_switch(protocol_to_use: ProtocolContext):
 
 # ---------------------
 
+temporarily_kill_ot_server()
 
 import opentrons.execute
 import logging
@@ -72,18 +79,24 @@ import logging
 logging.disable(logging.ERROR)
 
 protocol = opentrons.execute.get_protocol_api('2.5')
+
+#turn on lights
+protocol._hw_manager.hardware.set_lights(rails=True)
+
+#press button to kill
+set_button_as_kill_switch(protocol)
+
+
 print("Homing... ")
 protocol.home()
 
-set_button_as_kill_switch(protocol)
-
 plate = protocol.load_labware('corning_96_wellplate_360ul_flat', 1)
 
-laserController = laser.Controller(protocol=protocol)
+laserController = laser.Controller(protocol=protocol, print_position_in_relative=False)
 
 laserController.move_to_well(plate["A1"])
 
-laserController.move_z(plate["A1"].top(10).point.z)
+laserController.move_z(plate["A1"].top(5).point.z)
 
 
 def updateOffsetsFile(x: float, y: float, z: float):
@@ -115,11 +128,13 @@ def update_offset():
 
 def update_pos():
     pos = laserController.get_current_pos()
+    update_offset()
     pos_txt.set_text(("reverse",
                       f"Current position: X: {round(pos.x, 2)} Y: {round(pos.y, 2)} Z: {round(pos.z, 2)} . Offset  X: {round(x_offset, 2)} Y: {round(y_offset, 2)} Z: {round(z_offset, 2)} "))
 
 
 def save_offset():
+    update_offset()
     updateOffsetsFile(x=x_offset, y=y_offset, z=z_offset)
     message.set_text(f"Offset saved X: {x_offset} Y: {y_offset} Z: {z_offset}")
 
@@ -139,19 +154,19 @@ def show_or_exit(key):
     if key in ('s', 'S'):
         save_offset()
 
-    if key in ('k', 'K'):
+    if key in ('k', 'K', "shift up"):
         laserController.move_relz(movement_distance)
 
-    if key in ('m', 'M'):
+    if key in ('m', 'M', "shift down"):
         laserController.move_relz(-movement_distance)
     if key == "up":
         laserController.move_rely(movement_distance)
     if key == "down":
         laserController.move_rely(-movement_distance)
     if key == "left":
-        laserController.move_relx(movement_distance)
-    if key == "right":
         laserController.move_relx(-movement_distance)
+    if key == "right":
+        laserController.move_relx(movement_distance)
 
 
 text_header = (u"Laser Calibration")
@@ -164,7 +179,7 @@ movement_distance_txt = urwid.Text(('reverse', u"Movement distance: "))
 
 message = urwid.Text(('reverse', u""))
 
-num_key_expl = ", ".join([f"{k}:{movement_distances[k]}mm" for k in movement_distances])
+num_key_expl = ", ".join([f"{k}: {movement_distances[k]}mm " for k in movement_distances])
 
 keyboard = urwid.Text(f"""\
 KEYBOARD SHORTCUTS:
@@ -202,7 +217,7 @@ palette = [
     ('buttnf', 'white', 'dark blue', 'bold'),
 ]
 
-set_movement_distance(10)
+set_movement_distance(0.1)
 update_pos()
 loop = urwid.MainLoop(frame, palette, unhandled_input=show_or_exit)
 loop.run()
