@@ -39,16 +39,18 @@ def read_offsets_file():
     return offsets
 
 
+initial_offsets = read_offsets_file()
+
+
 class Controller(BaseModel):
 
     def __init__(self, **data: Any) -> None:
         super().__init__(**data)
         make_sure_port_is_started()
-        offsets = read_offsets_file()
-        self.x_offset = offsets["x"]
-        self.y_offset = offsets["y"]
-        self.z_offset = offsets["z"]
-
+    print_position_in_relative = True;
+    x_offset: float = initial_offsets["x"]
+    y_offset: float = initial_offsets["y"]
+    z_offset: float = initial_offsets["z"]
     mount: Mount = Mount.LEFT
     protocol: ProtocolContext
     z_abs_min = 49.5  # where the end of ferule is against base plate
